==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebColumnMovingServiceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingServiceDescription } from "./WebColumnMovingServiceDescription";
/**
 * @hidden
 */
var WebColumnMovingServiceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnMovingServiceDescriptionMetadata, _super);
    function WebColumnMovingServiceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingServiceDescriptionMetadata.b = function (a) {
        if (WebColumnMovingServiceDescriptionMetadata.a == null) {
            WebColumnMovingServiceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingServiceDescriptionMetadata.c(WebColumnMovingServiceDescriptionMetadata.a);
        }
        if (a.j(WebColumnMovingServiceDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnMovingServiceDescriptionMetadata.a);
    };
    WebColumnMovingServiceDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnMovingService");
        a.item("__packageNameWC", "String:grids");
    };
    WebColumnMovingServiceDescriptionMetadata.d = function (a) {
        WebColumnMovingServiceDescriptionMetadata.b(a);
        a.aa("WebColumnMovingService", function () { return new WebColumnMovingServiceDescription(); });
        a.z("WebColumnMovingService", WebColumnMovingServiceDescriptionMetadata.a);
    };
    WebColumnMovingServiceDescriptionMetadata.$t = markType(WebColumnMovingServiceDescriptionMetadata, 'WebColumnMovingServiceDescriptionMetadata');
    WebColumnMovingServiceDescriptionMetadata.a = null;
    return WebColumnMovingServiceDescriptionMetadata;
}(Base));
export { WebColumnMovingServiceDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebColumnMovingServiceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingServiceDescription } from "./WebColumnMovingServiceDescription";
/**
 * @hidden
 */
var WebColumnMovingServiceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnMovingServiceDescriptionMetadata, _super);
    function WebColumnMovingServiceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingServiceDescriptionMetadata.b = function (a) {
        if (WebColumnMovingServiceDescriptionMetadata.a == null) {
            WebColumnMovingServiceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingServiceDescriptionMetadata.c(WebColumnMovingServiceDescriptionMetadata.a);
        }
        if (a.k(WebColumnMovingServiceDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnMovingServiceDescriptionMetadata.a);
    };
    WebColumnMovingServiceDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnMovingService");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
    };
    WebColumnMovingServiceDescriptionMetadata.d = function (a) {
        WebColumnMovingServiceDescriptionMetadata.b(a);
        a.ac("WebColumnMovingService", function () { return new WebColumnMovingServiceDescription(); });
        a.ab("WebColumnMovingService", WebColumnMovingServiceDescriptionMetadata.a);
    };
    WebColumnMovingServiceDescriptionMetadata.$t = markType(WebColumnMovingServiceDescriptionMetadata, 'WebColumnMovingServiceDescriptionMetadata');
    WebColumnMovingServiceDescriptionMetadata.a = null;
    return WebColumnMovingServiceDescriptionMetadata;
}(Base));
export { WebColumnMovingServiceDescriptionMetadata };
